#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-wai
version:              0.11.1
visibility:           public
id:                   hspec-wai-0.11.1-2IHdLsaG0JbGrpZerW4ytg
key:                  hspec-wai-0.11.1-2IHdLsaG0JbGrpZerW4ytg
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Experimental Hspec support for testing WAI applications
description:          Experimental Hspec support for testing WAI applications
category:             Testing
abi:                  305969ccfc1f340771f665fd698148bb
exposed:              True
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck

hidden-modules:       Test.Hspec.Wai.Util Paths_hspec_wai
import-dirs:          /usr/lib/ghc-8.10.5/site-local/hspec-wai-0.11.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hspec-wai-0.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/hspec-wai-0.11.1
hs-libraries:         HShspec-wai-0.11.1-2IHdLsaG0JbGrpZerW4ytg
depends:
    QuickCheck-2.14.2-AlBcjlnVb6HBYuJ8lOviFD base-4.14.2.0
    base-compat-0.11.2-Eyusxyk2CrTGloLdon9bIK bytestring-0.10.12.0
    case-insensitive-1.2.1.0-G5jOpOHgp1lAnadtJPMHHB
    hspec-core-2.8.2-KLUu39SDCkuHXBcAtSZ1N9
    hspec-expectations-0.8.2-LN4PZWALM0nAyWtlGZbtK9
    http-types-0.12.3-JSCBEGU6f6MIPS3hXwEPIB text-1.2.4.1
    transformers-0.5.6.2 wai-3.2.3-6NrdunSiuKK6vnccK2cwty
    wai-extra-3.1.6-FKz4MHJx3sl2f6Nl0w7kAe

haddock-interfaces:   /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html:         /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

